@@ -51,13 +51,15 @@ const NumInput = ({
         onChange={(e: any) => onChange(id, format, Number(e.target.value))}
       />
     </label>
-    {error ? (
-      <div className="error">
-        <p>Error: {error}</p>
-      </div>
-    ) : (
-      ''
-    )}
+    {error.length ? (
+        <div className="error">
+          {error.map(Error => (
+            <p>Error: {Error}</p>
+          ))}
+        </div>
+      ) : (
+        ''
+      )}
   </div>
 );
 
